const awsIot = require('aws-iot-device-sdk');
const exec = require('await-exec');
const fs = require('fs');

const configPath = './awsIotConfig';
const configFile = configPath + '/config.json';
const keyPath = configPath + '/key.pem';
const certPath = configPath + '/cert.pem';
const caPath = configPath + '/ca.pem';
const hostPath = configPath + '/host';

// Executes krypton client to get open ID token by using SIM and Krypton
async function getCertificatesByKrypton(){
  let execResult = await exec("./krypton-iot");
  return JSON.parse(execResult.stdout);
}

// Initializes AWS credentials and set timer to refresh periodically
async function getDeviceBootstrapConfiguration(){
  if (!fs.existsSync(configPath)){
    fs.mkdirSync(configPath);
  }
  let config;
  if (!fs.existsSync(configFile)){
    let data = await getCertificatesByKrypton();
    fs.writeFileSync(keyPath, data.privateKey);
    fs.writeFileSync(certPath, data.certificate);
    fs.writeFileSync(caPath, data.rootCaCertificate);
    config = {
      keyPath: keyPath,
      certPath: certPath,
      caPath: caPath,
      clientId: data.clientId,
      host: data.host,
      region: data.region,
      debug: true
    };
    fs.writeFileSync(configFile, JSON.stringify(config));
  } else {
    config = JSON.parse(fs.readFileSync(configFile));
  }
  return config;
}

getDeviceBootstrapConfiguration().then((config) => {
  console.log(config);
  const device = awsIot.device(config);

  //
  // Device is an instance returned by mqtt.Client(), see mqtt.js for full
  // documentation.
  //
  device
    .on('connect', function() {
      console.log('connect');
      device.subscribe('topic_1');
      device.publish('topic_2', JSON.stringify({ test_data: 1}));
    });

  device
    .on('message', function(topic, payload) {
      console.log('message', topic, payload.toString());
    });

  device
    .on('error', function(error) {
      console.error('error', error);
    });
});
